@@ -4,12 +4,14 @@
 
 __author__ = """MIT Data To AI Lab"""
 __email__ = 'dailabmit@gmail.com'
-__version__ = '0.0.1'
+__version__ = '0.0.3'
 
 import os
 
 from mlblocks import discovery
 
+from sigpro.process_signals import process_signals
+
 _BASE_PATH = os.path.abspath(os.path.dirname(__file__))
 MLBLOCKS_PRIMITIVES = os.path.join(_BASE_PATH, 'primitives')
 
@@ -42,3 +44,6 @@ def get_primitives(name=None, primitive_type=None, primitive_subtype=None):
         filters['classifiers.subtype'] = primitive_subtype
 
     return discovery.find_primitives(name or 'sigpro', filters)
+
+
+__all__ = ('process_signals', )
