@@ -12,8 +12,8 @@ def test_fft():
     amplitude_values, frequency_values = fft(values, 10)
 
     # assert
-    expected_amplitude_values = [5. + 0.j, 0. + 0.j, 0. + 0.j, 0. + 0.j, 0. + 0.j]
-    expected_frequency_values = [0.0, 0.02, 0.04, -0.04, -0.02]
+    expected_amplitude_values = [5. + 0.j, 0. + 0.j]
+    expected_frequency_values = [0, 2]
     np.testing.assert_array_almost_equal(amplitude_values, expected_amplitude_values)
     np.testing.assert_array_almost_equal(frequency_values, expected_frequency_values)
 
@@ -26,7 +26,7 @@ def test_fft_real():
     amplitude_values, frequency_values = fft_real(values, 10)
 
     # assert
-    expected_amplitude_values = [4.0, 0.80901699, -0.30901699, -0.30901699, 0.80901699]
-    expected_frequency_values = [0.0, 0.02, 0.04, -0.04, -0.02]
+    expected_amplitude_values = [4.0, 0.80901699]
+    expected_frequency_values = [0, 2]
     np.testing.assert_array_almost_equal(amplitude_values, expected_amplitude_values)
     np.testing.assert_array_almost_equal(frequency_values, expected_frequency_values)
